pyy
===

`pyy` is a python library for creating and serving of (X)HTML pages.

For an overview of the foundation of `pyy` please read the `README` for
`pyy.html` [here](http://github.com/Knio/pyy/blob/dev/pyy/html/README.md).


Install
-------

The recommended way to install `pyy` is with
[`pip`](http://pypi.python.org/pypi/pip/):

    sudo pip install pyy


Modules
-------

*   `pyy.html` - Markup and document creation, validation, and rendering.
*   `pyy.server` - A lightweight and __highly experimental__ web server.
*   `pyy.web` - HTTP helper classes and functions.

Each module has a `README` which details and outlines its purpose as well as
how to properly use it.



Developed By
============

* Tom Flanagan - <theknio@gmail.com>
* Jake Wharton - <jakewharton@gmail.com>

Git repository located at
[github.com/Knio/pyy](http://github.com/Knio/pyy)


License
=======

    This file is part of pyy.

    pyy is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as
    published by the Free Software Foundation, either version 3 of
    the License, or (at your option) any later version.

    pyy is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General
    Public License along with pyy.  If not, see
    <http://www.gnu.org/licenses/>.
